@@ -2,7 +2,6 @@ import numpy as np
 import random
 import os
 import time
-import random
 from math import e,sqrt,sin,cos
 def sigmoid(x):
     return 1 / (1 + np.exp(-x))
@@ -102,11 +101,8 @@ def set_data(X, Y, batch_size, shake_data):
         return [0], [0]
     X = np.array(X)
     Y = np.array(Y)
-    #X = X.tolist()
-    #Y = Y.tolist()
     new_x = []
     new_y = []
-    print(X)
     for x in range(len(X)):
         new_x.append(X[x].tolist())
         new_y.append(Y[x].tolist())
@@ -277,6 +273,8 @@ class NeuralNetwork():
             return
         #x,y = prepare_data.set_data(x,y,batch_size, shake_data)
         #x_test, y_test = prepare_data.set_data(x_test, y_test, 999999, False)
+        x_copy = x.copy()
+        y_copy = y.copy()
         x,y = set_data(x,y,batch_size, shake_data)
         x_test, y_test = set_data(x_test, y_test, 999999, False)
         self.stats_error = []
@@ -286,11 +284,14 @@ class NeuralNetwork():
         if self.ai_system_list[-1].weights.shape[1] != y[0].shape[1]:
             print(f"TechAI.Error: Outputs {self.ai_system_list[-1].weights.shape[1]} - OutputData {y[0].shape[1]}")
         for train in range(epochs):
+            if shake_data == True:
+                x, y = set_data(x_copy, y_copy, batch_size, shake_data)
             self.update = [0]*len(self.ai_system_list)
             self.select_droupout_neurons()
             total_error = 0
             total_error_test = 0
             for nr in range(len(x)):
+                self.select_droupout_neurons()
                 forward = x[nr]
                 for i in range(self.hidden_layers):
                     forward = self.activation_fucntions[i + 1](np.dot(forward,self.ai_system_list[i].weights))
